p  { font-family: "Verdana, Arial" }
a  { font-family: "Verdana, Arial" }
td { font-family: "Verdana, Arial"; font-size: x-small }
th { font-family: "Verdana, Arial"; font-weight: bolder }
h3 { font-family: "Verdana, Arial" }
h2 { font-family: "Verdana, Arial" }
h1 { font-family: "Verdana, Arial" }
code { font-weight: bold }
